using ComponentPractice.Components;
using ComponentPractice.Data;
using ComponentPractice.Services;
using Microsoft.AspNetCore.Builder;
using Radzen;

namespace ComponentPractice
{
    public class Program
    {
        public static void Main(string[] args)
        {
            var builder = WebApplication.CreateBuilder(args);

            // Add services to the container.
            builder.Services.AddRazorComponents()
                .AddInteractiveServerComponents();

            // Add controllers
            builder.Services.AddControllers();

            // Add swagger
            builder.Services.AddEndpointsApiExplorer();
            builder.Services.AddSwaggerGen();

            builder.Services.AddRadzenComponents();

            builder.Services.AddSingleton<InMemoryData>();
            builder.Services.AddScoped<NorthwindDataService>();
            builder.Services.AddScoped<ToCSVService>();
            builder.Services.AddScoped<ExportService>();

            var app = builder.Build();

            // Configure the HTTP request pipeline.
            if (!app.Environment.IsDevelopment())
            {
                app.UseExceptionHandler("/Error");
                // The default HSTS value is 30 days. You may want to change this for production scenarios, see https://aka.ms/aspnetcore-hsts.
                app.UseHsts();
            }

            // Active swagger on Development Env.
            if (app.Environment.IsDevelopment())
            {
                app.UseSwagger();
                app.UseSwaggerUI();
            }

            app.UseHttpsRedirection();

            app.UseStaticFiles();
            app.UseAntiforgery();

            app.MapRazorComponents<App>()
                .AddInteractiveServerRenderMode();

            app.MapControllers();

            //app.Urls.Add("http://*:5000");

            app.Run();
        }
    }
}
